# Generated by Django 5.1.1 on 2024-10-01 20:42

import re

from django.db import migrations
from django.db import transaction


def convert_from_format_to_template(apps, schema_editor):
    # TODO: Is there a signal to disable?  I don't want documents getting moved while this is running

    StoragePath = apps.get_model("documents", "StoragePath")

    def convert_to_django_template_format(old_format):
        """
        Converts old Python string format (with {}) to Django template style (with {{ }}),
        while ignoring existing {{ ... }} placeholders.

        :param old_format: The old style format string (e.g., "{title} by {author}")
        :return: Converted string in Django Template style (e.g., "{{ title }} by {{ author }}")
        """

        # Step 1: Match placeholders with single curly braces but not those with double braces
        pattern = r"(?<!\{)\{(\w*)\}(?!\})"  # Matches {var} but not {{var}}

        # Step 2: Replace the placeholders with {{ var }} or {{ }}
        def replace_with_django(match):
            variable = match.group(1)  # The variable inside the braces
            return f"{{{{ {variable} }}}}"  # Convert to {{ variable }}

        # Apply the substitution
        converted_format = re.sub(pattern, replace_with_django, old_format)

        return converted_format

    with transaction.atomic():
        for storage_path in StoragePath.objects.all():
            storage_path.path = convert_to_django_template_format(storage_path.path)
            storage_path.save()


class Migration(migrations.Migration):
    dependencies = [
        ("documents", "1053_document_page_count"),
    ]

    operations = [
        migrations.RunPython(
            convert_from_format_to_template,
            # This is a one way migration
            migrations.RunPython.noop,
        ),
    ]
